import { Extension } from '@codemirror/state';
import { DOMEventMap, EditorView } from '@codemirror/view';

type EventHandler<event extends keyof DOMEventMap> = (e: DOMEventMap[event], v: EditorView) => void;
type Options = {
    /**
     * Determines how to render text. Defaults to `characters`.
     */
    displayText?: "blocks" | "characters";
    /**
     * Attach event handlers to the minimap container element.
     */
    eventHandlers?: {
        [event in keyof DOMEventMap]?: EventHandler<event>;
    };
    /**
     * The overlay shows the portion of the file currently in the viewport.
     * Defaults to `always`.
     */
    showOverlay?: "always" | "mouse-over";
};

declare function minimap(o?: Options): Extension;

export { minimap };
